//
// File: ShapeContainer.cc
// Created by: Sylvain MARECHAL <sylvain.marechal1@libertysurf.fr>
// Created on: Thu Jun  1 22:50:56 2006
//
#include <stdlib.h>
#ifdef __TURBOC__
#include "ShapeC~1.h"
#else
#include "ShapeContainer.h"
#endif

ShapeContainer::ShapeContainer() :
	m_currentShape (0)
{
	for( int i = 0; i < MAX_SHAPES; i ++ ) m_shapes[i] = NULL;
}

ShapeContainer::~ShapeContainer()
{
	// TODO: Use smart pointer everywhere
	// Currently caller has to allocate object with new
	for( int i = 0; i < MAX_SHAPES; i ++ ) if( m_shapes[i] ) delete m_shapes[i];
}

void ShapeContainer::AddShape( Shape * p )
{
	if( m_shapes[m_currentShape] ) m_shapes[m_currentShape]->SetSelected(false);
	int i;
	for( i = 0; i < MAX_SHAPES; i ++ )
	{
		if( m_shapes[i] == NULL ) break;
	}
	if( i == MAX_SHAPES ) i = 0;		
	// TODO: Use smart pointer everywhere
	if( m_shapes[i] ) delete m_shapes[i];
	m_shapes[i] = p;
	m_shapes[i]->SetSelected(true);
	m_currentShape = i;
}

void ShapeContainer::RemoveCurrentShape()
{
	// TODO: Use smart pointer everywhere
	if( m_shapes[m_currentShape] ) delete m_shapes[m_currentShape];
	m_shapes[m_currentShape] = NULL;
}

void ShapeContainer::MoveCurrentShape( int xInc, int yInc )
{
	if( m_shapes[m_currentShape] )
	{
		m_shapes[m_currentShape]->SetX( m_shapes[m_currentShape]->GetX() + xInc );
		m_shapes[m_currentShape]->SetY( m_shapes[m_currentShape]->GetY() + yInc );
	}
		
}

void ShapeContainer::SelectNextShape()
{
	if( m_shapes[m_currentShape] ) m_shapes[m_currentShape]->SetSelected(false);
	for( int i = m_currentShape+1; i < m_currentShape + MAX_SHAPES; i ++ )
	{
		if( m_shapes[i%MAX_SHAPES] )
		{
			m_currentShape = i%MAX_SHAPES;
			break;
		}
	}
	if( m_shapes[m_currentShape] ) m_shapes[m_currentShape]->SetSelected(true);
}

void ShapeContainer::EnlargeCurrent()
{
	if( m_shapes[m_currentShape] ) m_shapes[m_currentShape]->Bigger();
}

void ShapeContainer::MakeCurrentSmaller()
{
	if( m_shapes[m_currentShape] ) m_shapes[m_currentShape]->Smaller();
}

void ShapeContainer::HideAll()
{
	for( int i = 0; i < MAX_SHAPES; i ++ ) if( m_shapes[i] ) m_shapes[i]->Hide();
}

void ShapeContainer::ShowAll()
{
	for( int i = 0; i < MAX_SHAPES; i ++ ) if( m_shapes[i] ) m_shapes[i]->Show();
}
