//
// File: DessinFrame.cc
// Created by: Sylvain MARECHAL <sylvain.marechal1@libertysurf.fr>
// Created on: Thu Jun  1 17:52:37 2006
//

#include "wxDessinFrame.h"

BEGIN_EVENT_TABLE(DessinFrame, wxFrame)
	EVT_MENU(ID_Quit, DessinFrame::OnQuit)
	EVT_MENU(ID_SelectNext,DessinFrame::OnSelectNext)
	EVT_MENU(ID_DeleteCurrent,DessinFrame::OnDeleteCurrent)
	EVT_MENU(ID_Bigger,DessinFrame::OnBigger)
	EVT_MENU(ID_Smaller,DessinFrame::OnSmaller)
	EVT_MENU(ID_MoveLeft,DessinFrame::OnMoveLeft)
	EVT_MENU(ID_MoveRight,DessinFrame::OnMoveRight)
	EVT_MENU(ID_MoveBottom,DessinFrame::OnMoveBottom)
	EVT_MENU(ID_MoveTop,DessinFrame::OnMoveTop)
	//EVT_MENU(ID_NewPoint,DessinFrame::OnNewPoint)
	EVT_MENU(ID_NewCircle,DessinFrame::OnNewCircle)
	EVT_MENU(ID_NewLine, DessinFrame::OnNewLine)
	EVT_MENU(ID_NewRectangle, DessinFrame::OnNewRectangle)
	EVT_MENU(ID_About, DessinFrame::OnAbout)
END_EVENT_TABLE()

DessinFrame::DessinFrame(const wxString& title, const wxPoint& pos, const wxSize& size)
: wxFrame((wxFrame *)NULL, -1, title, pos, size)
{
	wxMenu *menuFile = new wxMenu;	
	menuFile->Append( ID_Quit, "E&xit" );
		
	// Note that label after \t is interpreted as an accelerator key
	// but it doesn't work (linux) with keypad
	wxMenu *menuShape = new wxMenu;
	//menuShape->Append( ID_NewPoint, "New &Point" );
	menuShape->Append( ID_NewCircle, "New &Circle" );
	menuShape->Append( ID_NewLine, "New &Line" );
	menuShape->Append( ID_NewRectangle, "New &Rectangle" );
	menuShape->AppendSeparator();
	menuShape->Append( ID_DeleteCurrent, "Delete current\tDel" );
	menuShape->AppendSeparator();
	menuShape->Append( ID_SelectNext, "Select next\tTab" );
	menuShape->AppendSeparator();
	menuShape->Append( ID_MoveLeft, "Move Left\tLeft" );
	menuShape->Append( ID_MoveRight, "Move Right\tRight" );
	menuShape->Append( ID_MoveTop, "Move Top\tUp" );
	menuShape->Append( ID_MoveBottom, "Move Bottom\tDown" );
	menuShape->Append( ID_Bigger, "Make it bigger\t+" );
	menuShape->Append( ID_Smaller, "Make it smaller\t-" );

	wxMenu *menuAbout = new wxMenu;	
	menuAbout->Append( ID_About, "&About..." );

	wxMenuBar *menuBar = new wxMenuBar;
	menuBar->Append( menuFile, "&File" );
	menuBar->Append( menuShape, "&Shape" );
	menuBar->Append( menuAbout, "&About" );
	
	SetMenuBar( menuBar );
	
	CreateStatusBar();
	SetStatusText( "Shapes and Co." );
	
	m_dessinWindow = new DessinWindow( this );
}

void DessinFrame::OnQuit(wxCommandEvent& WXUNUSED(event))
{
	Close(TRUE);
}

void DessinFrame::OnSelectNext(wxCommandEvent& WXUNUSED(event))
{
	if( m_dessinWindow ) m_dessinWindow->SelectNext();
}

void DessinFrame::OnDeleteCurrent(wxCommandEvent& WXUNUSED(event))
{
	if( m_dessinWindow ) m_dessinWindow->DeleteCurrent();
}

void DessinFrame::OnBigger(wxCommandEvent& WXUNUSED(event))
{
	if( m_dessinWindow ) m_dessinWindow->Bigger();
}

void DessinFrame::OnSmaller(wxCommandEvent& WXUNUSED(event))
{
	if( m_dessinWindow ) m_dessinWindow->Smaller();
}

void DessinFrame::OnMoveLeft(wxCommandEvent& WXUNUSED(event))
{
	if( m_dessinWindow ) m_dessinWindow->MoveLeft();
}

void DessinFrame::OnMoveRight(wxCommandEvent& WXUNUSED(event))
{
	if( m_dessinWindow ) m_dessinWindow->MoveRight();
}

void DessinFrame::OnMoveBottom(wxCommandEvent& WXUNUSED(event))
{
	if( m_dessinWindow ) m_dessinWindow->MoveBottom();
}

void DessinFrame::OnMoveTop(wxCommandEvent& WXUNUSED(event))
{
	if( m_dessinWindow ) m_dessinWindow->MoveTop();
}

void DessinFrame::OnNewPoint(wxCommandEvent& WXUNUSED(event))
{
	if( m_dessinWindow ) m_dessinWindow->NewPoint();
}

void DessinFrame::OnNewCircle(wxCommandEvent& WXUNUSED(event))
{
	if( m_dessinWindow ) m_dessinWindow->NewCircle();
}

void DessinFrame::OnNewLine(wxCommandEvent& WXUNUSED(event))
{
	if( m_dessinWindow ) m_dessinWindow->NewLine();
}

void DessinFrame::OnNewRectangle(wxCommandEvent& WXUNUSED(event))
{
	if( m_dessinWindow ) m_dessinWindow->NewRectangle();
}

void DessinFrame::OnAbout(wxCommandEvent& WXUNUSED(event))
{
	wxMessageBox("Shape sample - Sylvain MARECHAL",
		"About", wxOK | wxICON_INFORMATION, this);
}
