//
// File: DessinWindow.cc
// Created by: Sylvain MARECHAL <sylvain.marechal1@libertysurf.fr>
// Created on: Thu Jun  1 21:53:13 2006
//

#include "wxDessinWindow.h"
#include "Circle.h"
#include "Point.h"
#include "Line.h"
#include "Rectangle.h"

BEGIN_EVENT_TABLE(DessinWindow, wxWindow)
	EVT_KEY_DOWN(DessinWindow::OnKeyDown)
    EVT_PAINT(DessinWindow::OnPaint)
END_EVENT_TABLE()

DessinWindow::DessinWindow(wxWindow *parent) :
	wxWindow(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize,
                   wxRAISED_BORDER)
{
	SetBackgroundColour(*wxWHITE);
}


void DessinWindow::OnKeyDown(wxKeyEvent& event)
{
	wxString key;
    long keycode = event.GetKeyCode();
    switch ( keycode )
    {
        case WXK_TAB: key = _T("TAB"); SelectNext(); break;
        case WXK_DELETE: key = _T("DELETE"); DeleteCurrent(); break;
        case WXK_LEFT: key = _T("LEFT"); MoveLeft(); break;
        case WXK_UP: key = _T("UP"); MoveTop(); break;
        case WXK_RIGHT: key = _T("RIGHT"); MoveRight(); break;
        case WXK_DOWN: key = _T("DOWN"); MoveBottom(); break;
        //case WXK_ADD: key = _T("ADD"); break;
        //case WXK_SUBTRACT: key = _T("SUBTRACT"); break;
        case WXK_NUMPAD_ADD: key = _T("NUMPAD_ADD"); Bigger(); break;
        case WXK_NUMPAD_SUBTRACT: key = _T("NUMPAD_SUBTRACT"); Smaller(); break;
		default: key = _T("???"); break;
	}
	//wxMessageBox(key,
	//	"Message", wxOK | wxICON_INFORMATION, this);
}


void DessinWindow::OnPaint(wxPaintEvent& WXUNUSED(event))
{
	wxPaintDC dc(this);
	dc.SetTextForeground(*wxWHITE);
	//dc.DrawLabel(_T("Press keys here"), GetClientRect(), wxALIGN_CENTER);
	m_wxDisplay.SetDC( &dc );
	m_shapeContainer.ShowAll();
}

void DessinWindow::HideActionShow( void (DessinWindow::*pfAction)(void) )
{
	wxWindowDC dc(this);
	m_wxDisplay.SetDC( &dc );
	m_shapeContainer.HideAll();
	// Syntax to use a pointer to a member function
	(this->*pfAction)();
	m_shapeContainer.ShowAll();
}

void DessinWindow::_SelectNext()
{
	m_shapeContainer.SelectNextShape();
}

void DessinWindow::_DeleteCurrent()
{
	m_shapeContainer.RemoveCurrentShape();
}

void DessinWindow::_Bigger()
{
	m_shapeContainer.EnlargeCurrent();
}

void DessinWindow::_Smaller()
{
	m_shapeContainer.MakeCurrentSmaller();
}

void DessinWindow::_MoveLeft()
{
	m_shapeContainer.MoveCurrentShape( -1, 0 );
}

void DessinWindow::_MoveRight()
{
	m_shapeContainer.MoveCurrentShape( 1, 0 );
}

void DessinWindow::_MoveBottom()
{
	m_shapeContainer.MoveCurrentShape( 0, 1 );
}

void DessinWindow::_MoveTop()
{
	m_shapeContainer.MoveCurrentShape( 0, -1 );
}

void DessinWindow::_NewPoint()
{
	m_shapeContainer.AddShape( new Point(m_wxDisplay, GetRandomX(), GetRandomY()) );
	SetFocus();
}

void DessinWindow::_NewCircle()
{
	m_shapeContainer.AddShape( new Circle(m_wxDisplay, GetRandomX(), GetRandomY(), GetRandomX()/10+5) );
	SetFocus();
}

void DessinWindow::_NewLine()
{
	m_shapeContainer.AddShape( new Line(m_wxDisplay, GetRandomX(), GetRandomY(), GetRandomX(), GetRandomY()) );
	SetFocus();
}

void DessinWindow::_NewRectangle()
{
	m_shapeContainer.AddShape( new Rectangle(m_wxDisplay, GetRandomX(), GetRandomY(), GetRandomX()/10 + 20, GetRandomY() / 10 + 10 ) );
	SetFocus();
}

int DessinWindow::GetRandomNumber( int n )
{
	static bool s_first = true;
	if( s_first ) 
	{
		srand( time(NULL) );
		s_first = false;
	}
	int r = rand();
	return (r % n );
}

int DessinWindow::GetRandomX()
{
	wxSize size = GetClientSize();
    return GetRandomNumber( size.x);
}

int DessinWindow::GetRandomY()
{
	wxSize size = GetClientSize();
    return GetRandomNumber( size.y);
}
