//
// File: DessinWindow.h
// Created by: Sylvain MARECHAL <sylvain.marechal1@libertysurf.fr>
// Created on: Thu Jun  1 21:53:13 2006
//

#ifndef _DESSINWINDOW_H_
#define _DESSINWINDOW_H_
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif
#include <wx/wx.h>
#include "ShapeContainer.h"
#include "wxDisplay.h"

class DessinWindow : public wxWindow
{
	public:
		DessinWindow(wxWindow *parent);
	
		void OnKeyDown(wxKeyEvent& event);	
		void OnPaint(wxPaintEvent& WXUNUSED(event));
	
		// Be lazy with HideActionShow and method function pointer
		// to avoid code duplication
		void SelectNext() { HideActionShow( &DessinWindow::_SelectNext ); }
		void DeleteCurrent() { HideActionShow( &DessinWindow::_DeleteCurrent ); }
		void Bigger() { HideActionShow( &DessinWindow::_Bigger ); }
		void Smaller() { HideActionShow( &DessinWindow::_Smaller ); }
		void MoveLeft() { HideActionShow( &DessinWindow::_MoveLeft ); }
		void MoveRight() { HideActionShow( &DessinWindow::_MoveRight ); }
		void MoveBottom() { HideActionShow( &DessinWindow::_MoveBottom ); }
		void MoveTop() { HideActionShow( &DessinWindow::_MoveTop ); }
		void NewPoint() { HideActionShow( &DessinWindow::_NewPoint ); }
		void NewCircle() { HideActionShow( &DessinWindow::_NewCircle ); }
		void NewLine() { HideActionShow( &DessinWindow::_NewLine ); }
		void NewRectangle() { HideActionShow( &DessinWindow::_NewRectangle ); }
	private:
		void HideActionShow( void (DessinWindow::*)(void) );
		void _SelectNext();
		void _DeleteCurrent();
		void _Bigger();
		void _Smaller();
		void _MoveLeft();
		void _MoveRight();
		void _MoveBottom();
		void _MoveTop();
		void _NewPoint();
		void _NewCircle();
		void _NewLine();
		void _NewRectangle();

		int GetRandomNumber( int n );
		int GetRandomX();
		int GetRandomY();
	private:
		// The important objects are there
		ShapeContainer m_shapeContainer;
		wxDisplay m_wxDisplay;

		DECLARE_EVENT_TABLE()	
};


#endif	//_DESSINWINDOW_H_
